# Contributing

The [oaebu-workflows](https://github.com/The-Academic-Observatory/oaebu-workflows) is a dependent repository of the [observatory-platform](https://github.com/The-Academic-Observatory/observatory-platform).

We welcome contributions to the project, please see the [CONTRIBUTING.md file for the Observatory Platform](https://github.com/The-Academic-Observatory/observatory-platform//blob/main/CONTRIBUTING.md) for details about how to contribute to this repository.
